@@ -419,7 +419,7 @@ class VariableClUpdateLastTimestamp(ReadonlyVariable):
 
     def get(self):
         ini = SystemIni(self.parent)
-        return ini.getVar('update', 'last_update') or "0"
+        return ini.getVar('system', 'last_update') or "0"
 
 
 class VariableClUpdateBinhostTime(FieldValue, ReadonlyVariable):
@@ -1021,7 +1021,8 @@ class VariableClUpdateProfileUrl(Variable):
                     if (repo_name in self.rep_names and
                         self.Get('cl_action') == self.check_action):
                         raise CriticalError(
-                            _("You need update repositories before change profile"))
+                            _("You need to update the repositories before "
+                              "you change the profile"))
                 git = Git()
                 return git.get_url(profile, "origin") or self.default_url
         except CriticalError as e:
@@ -1652,5 +1653,5 @@ class VariableClUpdateEixRepositories(ReadonlyVariable):
     def get(self):
         return ", ".join(
             x.capitalize() for x in chain(
-                reversed(self.Get('update.cl_update_rep_name')),
+                self.Get('update.cl_update_rep_name'),
                 self.Get('update.cl_update_other_rep_name')))
